import { Backend, Options } from '@sentry/core';
import { SentryEvent, SentryResponse } from '@sentry/types';
import { TransportOptions } from './transports';
/**
 * Configuration options for the Sentry Node SDK.
 * @see NodeClient for more information.
 */
export interface NodeOptions extends Options {
    /**
     * Whether unhandled Promise rejections should be captured or not. If true,
     * this will install an error handler and prevent the process from crashing.
     * Defaults to false.
     */
    captureUnhandledRejections?: boolean;
    /** Callback that is executed when a fatal global error occurs. */
    onFatalError?(error: Error): void;
    /**
     * @inheritDoc
     */
    transportOptions?: TransportOptions;
}
/** The Sentry Node SDK Backend. */
export declare class NodeBackend implements Backend {
    private readonly options;
    /** Creates a new Node backend instance. */
    constructor(options?: NodeOptions);
    /**
     * @inheritDoc
     */
    install(): boolean;
    /**
     * @inheritDoc
     */
    eventFromException(exception: any): Promise<SentryEvent>;
    /**
     * @inheritDoc
     */
    eventFromMessage(message: string): Promise<SentryEvent>;
    /**
     * @inheritDoc
     */
    sendEvent(event: SentryEvent): Promise<SentryResponse>;
    /**
     * @inheritDoc
     */
    storeBreadcrumb(): boolean;
    /**
     * @inheritDoc
     */
    storeScope(): void;
}
