"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var hub_1 = require("@sentry/hub");
var domain = require("domain");
/**
 * Returns the latest global hub instance.
 *
 * If a hub is already registered in the global carrier but this module
 * contains a more recent version, it replaces the registered version.
 * Otherwise, the currently registered hub will be returned.
 */
function getDefaultHub() {
    var globalHub = hub_1.getDefaultHub();
    if (!domain.active) {
        return globalHub;
    }
    var carrier = domain.active.__SENTRY__;
    if (!carrier) {
        domain.active.__SENTRY__ = carrier = {};
    }
    if (!carrier.hub) {
        var top_1 = globalHub.getStackTop();
        carrier.hub = top_1 ? new hub_1.Hub(top_1.client, top_1.scope) : new hub_1.Hub();
    }
    return carrier.hub;
}
exports.getDefaultHub = getDefaultHub;
//# sourceMappingURL=hub.js.map