"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var hub_1 = require("../hub");
/** Global Promise Rejection handler */
var OnUnhandledRejection = /** @class */ (function () {
    function OnUnhandledRejection() {
        /**
         * @inheritDoc
         */
        this.name = 'OnUnhandledRejection';
    }
    /**
     * @inheritDoc
     */
    OnUnhandledRejection.prototype.install = function () {
        global.process.on('unhandledRejection', this.sendUnhandledPromise.bind(this));
    };
    /**
     * Send an exception with reason
     * @param reason string
     * @param promise promise
     */
    OnUnhandledRejection.prototype.sendUnhandledPromise = function (reason, promise) {
        var context = (promise.domain && promise.domain.sentryContext) || {};
        hub_1.getDefaultHub().withScope(function () {
            hub_1.getDefaultHub().configureScope(function (scope) {
                // Preserve backwards compatibility with raven-node for now
                if (context.user) {
                    scope.setUser(context.user);
                }
                if (context.tags) {
                    Object.keys(context.tags).forEach(function (key) {
                        scope.setTag(key, context.tags[key]);
                    });
                }
                if (context.extra) {
                    Object.keys(context.extra).forEach(function (key) {
                        scope.setExtra(key, context.extra[key]);
                    });
                }
                scope.setExtra('unhandledPromiseRejection', true);
            });
            hub_1.getDefaultHub().captureException(reason);
        });
    };
    return OnUnhandledRejection;
}());
exports.OnUnhandledRejection = OnUnhandledRejection;
//# sourceMappingURL=onunhandledrejection.js.map