/// <reference types="node" />
import { DSN } from '@sentry/core';
import { SentryEvent, SentryResponse, Transport, TransportOptions as BaseOptions } from '@sentry/types';
import * as http from 'http';
import * as https from 'https';
/** Internal used interface for typescript */
export interface HTTPRequest {
    request(options: http.RequestOptions | string | URL, callback?: (res: http.IncomingMessage) => void): http.ClientRequest;
}
/** Transport options */
export interface TransportOptions extends BaseOptions {
    /** Options for http.agent default: { keepAlive: true, maxSockets: 100 } */
    agentOptions?: http.AgentOptions;
    /** Define custom headers */
    headers?: http.IncomingHttpHeaders;
}
/** Base Transport class implementation */
export declare abstract class BaseTransport implements Transport {
    options: TransportOptions;
    /** DSN object */
    protected dsn: DSN;
    /** The Agent used for corresponding transport */
    protected client: http.Agent | https.Agent | undefined;
    /** Create instance and set this.dsn */
    constructor(options: TransportOptions);
    /** Returns a Sentry auth header string */
    private getAuthHeader;
    /** Returns a build request option object used by request */
    protected getRequestOptions(): http.RequestOptions;
    /** TODO */
    protected sendWithModule(httpModule: HTTPRequest, event: SentryEvent): Promise<SentryResponse>;
    /**
     * @inheritDoc
     */
    send(_: SentryEvent): Promise<SentryResponse>;
}
